@@ -5,7 +5,7 @@ from mct.utils import get_mot_config_context
 from .__version__ import VERSION, VERSION_STATUS, __version__
 from mct.utils import load_nifti, combine_weighted_sum
 from mct.components_loader import load_reconstruction_method, get_reconstruction_method_class
-
+from mct.reconstruction_methods import rCovSoS, rSoS, STARC
 
 __author__ = 'Robbert Harms'
 __date__ = '2017-09-09'
@@ -25,12 +25,12 @@ try:
 
         handlers:
             console:
-                class: mdt.log_handlers.StdOutHandler
+                class: mdt.lib.log_handlers.StdOutHandler
                 level: INFO
                 formatter: simple
 
             dispatch_handler:
-                class: mdt.log_handlers.LogDispatchHandler
+                class: mdt.lib.log_handlers.LogDispatchHandler
                 level: INFO
                 formatter: simple
 
@@ -45,5 +45,5 @@ try:
     '''
     logging_config.dictConfig(yaml.safe_load(config))
 
-except ValueError:
-    print('Logging disabled')
+except ValueError as ex:
+    print('Logging disabled: {}'.format(ex))
