@@ -8,7 +8,7 @@ To view more information about a method use the mct-method-info command.
 """
 import argparse
 from mct.components_loader import list_reconstruction_methods
-from mdt.shell_utils import BasicShellApplication
+from mdt.lib.shell_utils import BasicShellApplication
 import textwrap
 
 __author__ = 'Robbert Harms'
@@ -20,7 +20,7 @@ __email__ = "robbert.harms@maastrichtuniversity.nl"
 class ListMethods(BasicShellApplication):
 
     def __init__(self):
-        super(ListMethods, self).__init__()
+        super().__init__()
 
     def _get_arg_parser(self, doc_parser=False):
         description = textwrap.dedent(__doc__)
