@@ -6,7 +6,7 @@ This outputs the documentation of the desired method.
 """
 import argparse
 from mct import get_reconstruction_method_class
-from mdt.shell_utils import BasicShellApplication
+from mdt.lib.shell_utils import BasicShellApplication
 import textwrap
 
 __author__ = 'Robbert Harms'
@@ -18,7 +18,7 @@ __email__ = "robbert.harms@maastrichtuniversity.nl"
 class MethodInfo(BasicShellApplication):
 
     def __init__(self):
-        super(MethodInfo, self).__init__()
+        super().__init__()
 
     def _get_arg_parser(self, doc_parser=False):
         description = textwrap.dedent(__doc__)
